summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/machine/mapledev.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/machine/mapledev.h')
-rw-r--r--src/mame/machine/mapledev.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/mame/machine/mapledev.h b/src/mame/machine/mapledev.h
index 2a2b93ca93c..f8942d13853 100644
--- a/src/mame/machine/mapledev.h
+++ b/src/mame/machine/mapledev.h
@@ -10,19 +10,19 @@
class maple_device : public device_t
{
public:
- maple_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, UINT32 clock, const char *shortname, const char *source);
+ maple_device(const machine_config &mconfig, device_type type, const char *name, const char *tag, device_t *owner, uint32_t clock, const char *shortname, const char *source);
static void static_set_host(device_t &device, const char *_host_tag, int _host_port);
- virtual void maple_w(const UINT32 *data, UINT32 in_size) = 0;
- void maple_r(UINT32 *data, UINT32 &out_size, bool &partial);
+ virtual void maple_w(const uint32_t *data, uint32_t in_size) = 0;
+ void maple_r(uint32_t *data, uint32_t &out_size, bool &partial);
virtual void maple_reset();
protected:
enum { TIMER_ID = 1000 };
- UINT32 reply_size;
+ uint32_t reply_size;
bool reply_partial;
- UINT32 reply_buffer[256];
+ uint32_t reply_buffer[256];
// device-level overrides
virtual void device_start() override;
@@ -32,11 +32,11 @@ protected:
void reply_ready_with_delay();
// Copy a string and complete it with spaces up to size len
- void copy_with_spaces(UINT8 *dest, const char *source, int len);
+ void copy_with_spaces(uint8_t *dest, const char *source, int len);
- // Setup the first UINT32 of reply with the type, source and length.
+ // Setup the first uint32_t of reply with the type, source and length.
// Also setup reply_size and clear reply_partial
- void reply_start(UINT8 code, UINT8 source, UINT8 size);
+ void reply_start(uint8_t code, uint8_t source, uint8_t size);
// Configuration
class maple_dc_device *host;